@@ -24,10 +24,11 @@ class ASGIHTTPConnection:
         request = self._create_request_from_scope(send)
         receiver_task = asyncio.ensure_future(self.handle_messages(request, receive))
         handler_task = asyncio.ensure_future(self.handle_request(request, send))
-        _, pending = await asyncio.wait(
+        done, pending = await asyncio.wait(
             [handler_task, receiver_task], return_when=asyncio.FIRST_COMPLETED
         )
         await _cancel_tasks(pending)
+        _raise_exceptions(done)
 
     async def handle_messages(self, request: Request, receive: Callable) -> None:
         while True:
@@ -61,6 +62,7 @@ class ASGIHTTPConnection:
             max_content_length=self.app.config["MAX_CONTENT_LENGTH"],
             body_timeout=self.app.config["BODY_TIMEOUT"],
             send_push_promise=partial(self._send_push_promise, send),
+            scope=self.scope,
         )
 
     async def handle_request(self, request: Request, send: Callable) -> None:
@@ -110,10 +112,11 @@ class ASGIWebsocketConnection:
         websocket = self._create_websocket_from_scope(send)
         receiver_task = asyncio.ensure_future(self.handle_messages(receive))
         handler_task = asyncio.ensure_future(self.handle_websocket(websocket, send))
-        _, pending = await asyncio.wait(
+        done, pending = await asyncio.wait(
             [handler_task, receiver_task], return_when=asyncio.FIRST_COMPLETED
         )
         await _cancel_tasks(pending)
+        _raise_exceptions(done)
 
     async def handle_messages(self, receive: Callable) -> None:
         while True:
@@ -221,6 +224,10 @@ async def _cancel_tasks(tasks: Set[asyncio.Future]) -> None:
     for task in tasks:
         task.cancel()
     await asyncio.gather(*tasks, return_exceptions=True)
+    _raise_exceptions(tasks)
+
+
+def _raise_exceptions(tasks: Set[asyncio.Future]) -> None:
     # Raise any unexcepted exceptions
     for task in tasks:
         if not task.cancelled() and task.exception() is not None:
